from typing import Literal
from pydantic import Field

from ...models import SelectOption
from ._base_property import BaseProperty, NotionPropertyType


class MultiSelectProperty(BaseProperty[Literal[NotionPropertyType.MULTI_SELECT]]):
    """Notionのmulti_selectプロパティ"""

    type: Literal[NotionPropertyType.MULTI_SELECT] = Field(
        NotionPropertyType.MULTI_SELECT, description="プロパティタイプ"
    )

    multi_select: list[SelectOption] = Field(
        default_factory=list, description="選択されたオプション配列"
    )

    def get_value(self) -> list[str]:
        """
        multi_select プロパティから選択されたオプション名のリストを取得

        Returns:
            list[str]: 選択されたオプション名のリスト（未選択の場合は空リスト）

        Examples:
            - 単一選択: ["タグA"]
            - 複数選択: ["タグA", "タグB", "タグC"]
            - 未選択: []
        """
        return [option.name for option in self.multi_select]



from typing import Literal

from pydantic import Field

from ._base_config import BasePropertyConfig
from ....models.primitives import EmptyObject
from ....properties.base_properties._base_property import NotionPropertyType


class PeoplePropertyConfig(BasePropertyConfig[Literal[NotionPropertyType.PEOPLE]]):
    """Notionのpeopleプロパティ設定"""

    type: Literal[NotionPropertyType.PEOPLE] = Field(
        NotionPropertyType.PEOPLE, description="プロパティタイプ"
    )
    people: EmptyObject = Field(
        default_factory=EmptyObject, description="people設定"
    )



from typing import Literal
from pydantic import Field

from ...models import StatusOption
from ._base_property import BaseProperty, NotionPropertyType


class StatusProperty(BaseProperty[Literal[NotionPropertyType.STATUS]]):
    """Notionのstatusプロパティ"""

    type: Literal[NotionPropertyType.STATUS] = Field(
        NotionPropertyType.STATUS, description="プロパティタイプ"
    )

    status: StatusOption | None = Field(
        None, description="現在のステータス（設定されていない場合はnull）"
    )

    def get_value(self) -> str | None:
        """
        status プロパティから現在のステータス名を取得

        Returns:
            str | None: ステータス名、未設定の場合はNone

        Note:
            - statusプロパティはselectと似ていますが、進捗管理に特化したプロパティです

        Examples:
            - 進行中: "進行中"
            - 完了: "完了"
            - 未設定: None
        """
        return self.status.name if self.status else None



from typing import Literal

from pydantic import Field

from ...models import PartialUser, User
from ._base_property import BaseProperty, NotionPropertyType


class CreatedByProperty(BaseProperty[Literal[NotionPropertyType.CREATED_BY]]):
    """Notionのcreated_byプロパティ"""

    type: Literal[NotionPropertyType.CREATED_BY] = Field(
        NotionPropertyType.CREATED_BY, description="プロパティタイプ"
    )

    created_by: PartialUser | User = Field(..., description="作成者情報")

    def get_value(self) -> str:
        """created_by プロパティから作成者名を取得"""
        name = getattr(self.created_by, "name", None)
        return name or ""



from typing import Literal
from pydantic import Field, StrictStr

from ._base_property import BaseProperty, NotionPropertyType


class UrlProperty(BaseProperty[Literal[NotionPropertyType.URL]]):
    """Notionのurlプロパティ"""

    type: Literal[NotionPropertyType.URL] = Field(
        NotionPropertyType.URL, description="プロパティタイプ"
    )

    url: StrictStr | None = Field(None, description="URL（設定されていない場合はnull）")

    def get_value(self) -> str | None:
        """
        url プロパティからURLを取得

        Returns:
            str | None: URL文字列、未設定の場合はNone

        Examples:
            - 有効なURL: "https://example.com"
            - 未設定: None
        """
        return self.url



from typing import Literal

from pydantic import Field

from ...models import PartialUser, User
from ._base_property import BaseProperty, NotionPropertyType


class LastEditedByProperty(BaseProperty[Literal[NotionPropertyType.LAST_EDITED_BY]]):
    """Notionのlast_edited_byプロパティ"""

    type: Literal[NotionPropertyType.LAST_EDITED_BY] = Field(
        NotionPropertyType.LAST_EDITED_BY, description="プロパティタイプ"
    )

    last_edited_by: PartialUser | User = Field(..., description="最終編集者情報")

    def get_value(self) -> str:
        """last_edited_by プロパティから最終編集者名を取得"""
        name = getattr(self.last_edited_by, "name", None)
        return name or ""



from typing import Literal

from pydantic import Field, StrictStr

from ._base_property import BaseProperty, NotionPropertyType


class CreatedTimeProperty(BaseProperty[Literal[NotionPropertyType.CREATED_TIME]]):
    """Notionのcreated_timeプロパティ"""

    type: Literal[NotionPropertyType.CREATED_TIME] = Field(
        NotionPropertyType.CREATED_TIME, description="プロパティタイプ"
    )

    created_time: StrictStr = Field(..., description="作成日時（ISO 8601形式）")

    def get_value(self) -> str:
        """created_time プロパティから作成日時を取得"""
        return self.created_time



"""Common request types used across Notion API requests.

基本的なリクエスト型の定義。
TypeScript SDKの定義に準拠しています。
"""

from typing import Literal

from pydantic import BaseModel, Field, StrictBool, StrictStr

# 基本型エイリアス
IdRequest = str
StringRequest = str
TextRequest = str
EmojiRequest = str
TimeZoneRequest = str


class AnnotationRequest(BaseModel):
    """テキストの装飾情報（太字、斜体など）."""

    bold: StrictBool | None = None
    italic: StrictBool | None = None
    strikethrough: StrictBool | None = None
    underline: StrictBool | None = None
    code: StrictBool | None = None
    color: str | None = None  # ApiColor


class DateRequest(BaseModel):
    """日付リクエスト."""

    start: StrictStr
    end: StrictStr | None = None
    time_zone: TimeZoneRequest | None = None


class PartialUserObjectRequest(BaseModel):
    """部分的なユーザーオブジェクト（ID参照用）."""

    id: IdRequest
    object: Literal["user"] | None = None


class GroupObjectRequest(BaseModel):
    """グループオブジェクト."""

    id: IdRequest
    name: StrictStr | None = None
    object: Literal["group"] | None = None


class RelationItemRequest(BaseModel):
    """リレーションプロパティのアイテム."""

    id: IdRequest


# Select/MultiSelect/Status用の選択肢リクエスト
class SelectPropertyItemRequest(BaseModel):
    """Select/MultiSelect/Status用の選択肢.

    IDまたは名前のいずれかで指定可能。
    """

    id: StringRequest | None = None
    name: TextRequest | None = None
    color: str | None = None  # SelectColor
    description: TextRequest | None = None

    class Config:
        """Pydantic設定."""

        # IDまたは名前のいずれかが必須
        # どちらも指定された場合はIDが優先される
        pass
